<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>隠しショートカット</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>これらのハードコードされたショートカットは、[環境設定] → [ショートカット] で他のアクションにも割り当てられている場合は上書きされます。</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>ウィンドウを閉じるか全画面表示を終了する</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>→</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>次の画像</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Space</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>最後の画像</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>←</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>前の画像</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>最初の画像</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="97"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>全画面表示で起動する(タイリングウィンドウマネージャーで便利です)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>スクリーンショットを撮る(非推奨、代わりに Screengrab を使用して下さい)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="114"/>
        <source>DIR</source>
        <translation>DIR</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="114"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>スクリーンショットを作成し、GUIを表示せずにディレクトリに保存します(非推奨、代わりに Screengrab を使用して下さい)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="120"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[ファイル1, ファイル2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>未知のエラー</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>未知のエラー</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>About</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>A simple and fast image viewer</source>
        <translation>シンプルで高速な画像ビューアー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Copyright (C) </source>
        <translation>Copyright (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>LXQt Project</source>
        <translation>LXQt プロジェクト</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Development: </source>
        <translation>開発: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>Author: </source>
        <translation>作成者: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Open File</source>
        <translation>ファイルを開く</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <location filename="../mainwindow.cpp" line="575"/>
        <source>Image files (%1)</source>
        <translation>画像ファイル (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Open directory</source>
        <translation>ディレクトリを開く</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>Save File</source>
        <translation>ファイルの保存</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="724"/>
        <location filename="../mainwindow.cpp" line="730"/>
        <location filename="../mainwindow.cpp" line="736"/>
        <location filename="../mainwindow.cpp" line="742"/>
        <location filename="../mainwindow.cpp" line="917"/>
        <source>%1/%2 Frames</source>
        <translation>%1/%2 フレーム</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (ロード中...) - 画像ビューアー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="902"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (読み込めません) - 画像ビューアー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - 画像ビューアー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>[*]Image Viewer</source>
        <translation>[*]画像ビューアー</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1397"/>
        <source>Thumbnails</source>
        <translation>サムネイル</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1492"/>
        <source>EXIF Data</source>
        <translation>Exif データ</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>消去(&amp;C)</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>ショートカットを消去するには、編集モードで
修飾キー (訳注: Alt, Ctrl, Shift) を押します。</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="216"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="217"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="343"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;警告: 複数のショートカットを検出しました！&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="360"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;複数のショートカットには対応しません。&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>この画像形式で保存できません！</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>サイズ:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>パス:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="47"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="48"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="136"/>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="139"/>
        <source>Stop</source>
        <translation>中止</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="142"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="149"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>画像ビューアー</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recent Files</source>
        <translation>最近使用したファイル(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <location filename="../mainwindow.ui" line="709"/>
        <source>Annotations Toolbar</source>
        <translation>注釈ツールバー</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>&amp;About</source>
        <translation>このアプリケーションについて(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="251"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="272"/>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>Save &amp;As</source>
        <translation>名前を付けて保存(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="287"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Zoom &amp;In</source>
        <translation>拡大(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Zoom &amp;Out</source>
        <translation>縮小(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>クリップボードへコピー(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="344"/>
        <source>Next File</source>
        <translation>次のファイル</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="356"/>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Previous File</source>
        <translation>前のファイル</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>アプリケーションで開く(&amp;W)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <source>Sorting</source>
        <translation>ソート</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>隠しショートカット(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>&amp;Open…</source>
        <translation>開く(&amp;O)…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="260"/>
        <source>&amp;Reload File</source>
        <translation>ファイルの再読み込み(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="347"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Original Size</source>
        <translation>原寸大</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="389"/>
        <source>&amp;Fit</source>
        <translation>フィット(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>時計方向に回転(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>反時計方向に回転(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>P&amp;references</source>
        <translation>設定(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="427"/>
        <source>&amp;Print</source>
        <translation>印刷(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>First File</source>
        <translation>最初のファイル</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Last File</source>
        <translation>最後のファイル</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="454"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>&amp;New Window</source>
        <translation>新しいウィンドウ(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Flip &amp;Horizontally</source>
        <translation>水平方向に反転(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="478"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>Capture Screenshot</source>
        <translation>スクリーンショットを撮る</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="495"/>
        <source>F&amp;ull Screen</source>
        <translation>全画面表示(&amp;U)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="507"/>
        <source>Flip &amp;Vertically</source>
        <translation>垂直方向に反転(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="510"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>クリップボードから貼り付け(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>&amp;Slide Show</source>
        <translation>スライドショー(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>&amp;Delete</source>
        <translation>削除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="551"/>
        <source>Show Thumbnails</source>
        <translation>サムネイルの表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>File Properties</source>
        <translation>ファイルのプロパティ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>Open &amp;Directory</source>
        <translation>ディレクトリを開く(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="575"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Upload</source>
        <translation>アップロード</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="587"/>
        <source>Upload the image</source>
        <translation>画像をアップロードする</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="598"/>
        <source>Show EXIF Data</source>
        <translation>Exif データの表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>No Tool</source>
        <translation>ツール解除</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Deselect all drawing tools</source>
        <translation>描画ツールの選択をすべて解除する</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="625"/>
        <source>Draw Arrow</source>
        <translation>矢印を描く</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="628"/>
        <source>Draw an arrow</source>
        <translation>矢印を描く</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="640"/>
        <source>Draw Rectangle</source>
        <translation>四角を描く</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="643"/>
        <source>Draw a hollow rectangle</source>
        <translation>中空の四角を描く</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="655"/>
        <source>Draw Circle</source>
        <translation>円を描く</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="658"/>
        <source>Draw a hollow circle</source>
        <translation>中空の円を描く</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Draw Number</source>
        <translation>番号を描く</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="673"/>
        <source>Draw incrementing numbers</source>
        <translation>増加する数字を描く</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="681"/>
        <location filename="../mainwindow.ui" line="684"/>
        <source>Menubar</source>
        <translation>メニューバー</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="687"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>&amp;Main Toolbar</source>
        <translation>メインツールバー(&amp;M)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="698"/>
        <source>Main Toolbar</source>
        <translation>メインツールバー</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="706"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>注釈ツールバー(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <location filename="../mainwindow.ui" line="720"/>
        <source>Show Outline</source>
        <translation>枠線の表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="723"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="731"/>
        <source>Copy Pa&amp;th</source>
        <translation>パスのコピー(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="734"/>
        <source>Copy path</source>
        <translation>パスのコピー</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="742"/>
        <location filename="../mainwindow.ui" line="745"/>
        <source>Rename</source>
        <translation>名前の変更</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="748"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="757"/>
        <source>Resize</source>
        <translation>サイズの変更</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>&amp;By File Name</source>
        <translation>名前順(&amp;B)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="768"/>
        <source>By File Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="776"/>
        <source>By &amp;Modification Time</source>
        <translation>更新日時順(&amp;M)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>By Modification Time</source>
        <translation>更新日時</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="787"/>
        <source>By C&amp;reation Time</source>
        <translation>作成日時順(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="790"/>
        <source>By Creation Time</source>
        <translation>作成日時</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="798"/>
        <source>By File &amp;Size</source>
        <translation>サイズ順(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>By File Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="809"/>
        <source>By File &amp;Type</source>
        <translation>種類順(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="812"/>
        <source>By File Type</source>
        <translation>種類</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="817"/>
        <source>Next Frame</source>
        <translation>次のフレーム</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="820"/>
        <source>Ctrl+Right</source>
        <translation>Ctrl+右</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="825"/>
        <source>Previous Frame</source>
        <translation>前のフレーム</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Ctrl+Left</source>
        <translation>Ctrl+左</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="833"/>
        <source>First Frame</source>
        <translation>最初のフレーム</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Last Frame</source>
        <translation>最後のフレーム</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="849"/>
        <source>Solid Background</source>
        <translation>単色の背景</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>ファイル(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&amp;Help</source>
        <translation>ヘルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="108"/>
        <source>Go</source>
        <translation>移動</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>&amp;View</source>
        <translation>表示(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>&amp;Edit</source>
        <translation>編集(&amp;E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="179"/>
        <source>Toolbar</source>
        <translation>ツールバー</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>アイコンテーマ:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>サムネイル作成のファイルサイズ制限:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>通常の背景色:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>全画面表示の背景色:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>最近使用したファイルの最大数:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="228"/>
        <source>Slide show interval (seconds):</source>
        <translation>スライドショーの間隔(秒):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="249"/>
        <source>Show image outline by default</source>
        <translation>既定では画像の枠線を表示する</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>既定では注釈ツールバーを表示する</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="256"/>
        <source>Fit images when navigating</source>
        <translation>ナビゲーション時に画像をフィットする</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>サムネイル画像の大きさ:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation>システムのゴミ箱を使用する(確認ダイアログを表示しません)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>ウィンドウ</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>既定ではサムネイル・ドックを表示する</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation>既定では Exif データのドックを表示する</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>既定ではメニューバーを表示する</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>既定ではメインツールバーを表示する</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>画像</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>May work only with images which have valid color spaces.
Reload current image to see the effect.</source>
        <translation>有効な色空間を持つ画像でのみ動作するでしょう。
効果を確認するには現在の画像を再ロードして下さい。</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="183"/>
        <source>Color space:</source>
        <translation>色空間:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="195"/>
        <source>None</source>
        <translation>未定</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>sRGB (supported by most monitors)</source>
        <translation>sRGB (ほとんどのモニタでサポート)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="205"/>
        <source>Linear sRGB (linear gamma)</source>
        <translation>リニア sRGB (リニアガンマ)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>Adobe RGB</source>
        <translation>Adobe RGB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>DisplayP3 (wide-gamut screens)</source>
        <translation>DisplayP3 (広色域スクリーン)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>ProPhotoRgb</source>
        <translation>ProPhotoRgb</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="242"/>
        <source>Solid background by default</source>
        <translation>デフォルトでは単色の背景</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="263"/>
        <source>Smooth images on zooming</source>
        <translation>ズーム時に画像を滑らかにする</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="271"/>
        <source>Shortcuts</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="290"/>
        <source>Action</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="295"/>
        <source>Shortcut</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="303"/>
        <source>Default</source>
        <translation>既定値</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>全般</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="1098"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>画像のサイズを変更</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>幅</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>高さ</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>現在のサイズ:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>新しいサイズ:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> ピクセル</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>アスペクト比を保つ</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>スクリーンショット</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>スクリーンショットを撮る</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>領域</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>画面全体</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>現在のウィンドウのみ</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>画面の範囲をキャプチャーする</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>マウスカーソルを含む</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>待ち時間:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>ウィンドウのタイトルと枠を含む</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>アップロード</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>コピーする</translation>
    </message>
</context>
</TS>
